// texts to translate
var texts = {
    selection : "Selección",
    netselection : "Selección de gráfico",
    visualization : "Visualización",
    nodes : "Nodos",
    general: "General",
    particular: "Particular",
    links: "Enlaces",
    apply: "Aplicar",
    filter: "Filtrar",
    select: "Seleccionar",
    clear: "Limpiar",
    add: "Añadir",
    simpleadvanced: "Simple/avanzado",
    nodesattributes: "Atributos de nodos",
    linksattributes: "Atributos de enlaces",
    noitemsselected: "Sin items seleccionados",
    alertnonodes: "¡No hay nodos seleccionados! Presiona shift para seleccionar nodos.",
    alertnonodestable: "¡No hay nodos seleccionados en la tabla!",
    repulsion: "Repulsión",
    distance: "Distancia",
    loading: "Cargando...",
    pdfexport: "Exportación PDF",
    svgexport: "Exportación SVG",
	adjustsymbols: "Fijar símbolos",
    showhidelabels: "Mostrar/ocultar etiquetas",
    showhidelegend: "Mostrar/ocultar leyenda",
    showhideaxes: "Mostrar/ocultar ejes",
    showhideimages: "Mostrar/ocultar imágenes",
    showhidesidebar: "Mostrar/ocultar control lateral",
    stopresume: "Parar/reanudar",
	netheatmap: "Red/mapa de color",
    isolateselection: "Filtrar selección",
    resetfilter: "Quitar filtro",
    selectall: "Seleccionar todos/ninguno",
    selectneighbors: "Añadir vecinos",
    egoNet: "EgoRed",
    tableselection: "Marcados en la tabla",
    reset: "Reiniciar",
    directional: "Direccional",
    degree: "grado",
    none: "Nada",
    downloadtable: "Descargar tabla",
    total: "Total",
    concoincidences: "Coincidencias condicionales",
    coincidences: "Coincidencias",
    ofsomeone: "de",
    withsomeone: "con",
    incidences: "Incidencias",
    ltexpected: "< Esperadas",
    gtexpected: "> Esperadas",
    confidence: "Intervalo de confianza",
    subjectselect: "Selección de eventos",
    Label: "Etiqueta",
    Group: "Grupo",
	OrderA: "A Orden",
	OrderD: "D Orden",
    Size: "Tamaño",
    Color: "Color",
    Shape: "Forma",
    Slegend: "Sleyenda",
    Width: "Anchura",
    Weight: "Ponderación",
	Intensity: "Intensidad",
    Text: "Texto",
    Show: "Mostrar",
    Hide: "Ocultar",
    circle: "Círculo",
    cross: "Cruz",
    diamond: "Diamante",
    square: "Cuadrado",
    "triangle-down": "Triangulo-abajo",
    "triangle-up": "Triangulo-arriba",
	trianglesquare: "Triángulo/cuadrado",
	selectacolorscale: "Selecciona una escala de color para ",
    selecta: "Selecciona un/una ",
	outof: "de"
  };
